==> jc-1.4.0.tar.gz: javax/swing/JRootPane__24AccessibleJRootPane.c <==
// public class javax.swing.JRootPane$AccessibleJRootPane

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 13eec6fc3dc83b49 javax_accessibility_AccessibleRole
// @dep_class 83369470a2cd3968 javax_swing_JRootPane
// @dep_class b2cd729d8d354462 javax_swing_JRootPane__24AccessibleJRootPane

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_accessibility_AccessibleRole
// @dep_header javax_swing_JRootPane
// @dep_header javax_swing_JRootPane__24AccessibleJRootPane

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/accessibility/AccessibleRole.h"
#include "javax/swing/JRootPane.h"
#include "javax/swing/JRootPane__24AccessibleJRootPane.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_swing_JRootPane__24AccessibleJRootPane$initial_value$serialVersionUID = _JC_JLONG(1082432482784468088);
static _jc_field _jc_javax_swing_JRootPane__24AccessibleJRootPane$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields[] = {
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JRootPane__24AccessibleJRootPane, _init$52f4ad9f2989aeee);

void
_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *this)
{
	struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(77);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.accessibility.AccessibleRole getAccessibleRole()
//

static _jc_linenum _jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$getAccessibleRole$eaa05a502d0ede18[];

static const unsigned char _jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$getAccessibleRole$eaa05a502d0ede18[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$getAccessibleRole$eaa05a502d0ede18 = {
	.name=			"getAccessibleRole",
	.signature=		"()Ljavax/accessibility/AccessibleRole;",
	.class=			&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	.return_type=		&_jc_javax_accessibility_AccessibleRole$type,
	.param_ptypes=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$getAccessibleRole$eaa05a502d0ede18,
	.signature_hash=	_JC_JLONG(0xeaa05a502d0ede18),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable, javax_swing_JRootPane__24AccessibleJRootPane.getAccessibleRole$eaa05a502d0ede18) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$getAccessibleRole$eaa05a502d0ede18
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JRootPane__24AccessibleJRootPane, getAccessibleRole$eaa05a502d0ede18);

_jc_javax_accessibility_AccessibleRole$object *
_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *const env, _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *this)
{
	struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *r0;
	struct _jc_javax_accessibility_AccessibleRole$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(86);				// 0
	r1 = _JC_STATIC_FIELD(env, javax_accessibility_AccessibleRole, ROOT__5fPANE, 0);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$methods[] = {
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$getAccessibleRole$eaa05a502d0ede18
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_98[] = {
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[98]=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_98,
	[113]=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/accessibility/AccessibleRole",	_JC_JLONG(0x13eec6fc3dc83b49) },
	{ "javax/swing/JRootPane",	_JC_JLONG(0x83369470a2cd3968) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype _jc_javax_swing_JRootPane__24AccessibleJRootPane$type = {
    .type= {
	.name=			"javax/swing/JRootPane$AccessibleJRootPane",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xb2cd729d8d354462),
		.source_file=		"JRootPane.java",
		.instance_size=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$refs) + sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields) / sizeof(*_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields),
		.fields=		_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields,
		.num_methods=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$methods) / sizeof(*_jc_javax_swing_JRootPane__24AccessibleJRootPane$methods),
		.methods=		_jc_javax_swing_JRootPane__24AccessibleJRootPane$methods,
		.instanceof_hash_table=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_fields,
		.outer_class=		&_jc_javax_swing_JRootPane$type,
		.num_class_depends=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends) / sizeof(*_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends),
		.class_depends=		_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_JRootPane__24AccessibleJRootPane= {
	    .getAccessibleRole$eaa05a502d0ede18=
		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/JRootPane__24AccessibleJRootPane.c <==
// public class javax.swing.JRootPane$AccessibleJRootPane

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 13eec6fc3dc83b49 javax_accessibility_AccessibleRole
// @dep_class 83369470a2cd3968 javax_swing_JRootPane
// @dep_class b2cd729d8d354462 javax_swing_JRootPane__24AccessibleJRootPane

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_accessibility_AccessibleRole
// @dep_header javax_swing_JRootPane
// @dep_header javax_swing_JRootPane__24AccessibleJRootPane

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/accessibility/AccessibleRole.h"
#include "javax/swing/JRootPane.h"
#include "javax/swing/JRootPane__24AccessibleJRootPane.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_swing_JRootPane__24AccessibleJRootPane$initial_value$serialVersionUID = _JC_JLONG(1082432482784468088);
static _jc_field _jc_javax_swing_JRootPane__24AccessibleJRootPane$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields[] = {
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JRootPane__24AccessibleJRootPane, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *this)
{
	struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(77);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.accessibility.AccessibleRole getAccessibleRole()
//

static _jc_linenum _jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$getAccessibleRole$eaa05a502d0ede18[];

static const unsigned char _jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$getAccessibleRole$eaa05a502d0ede18[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$getAccessibleRole$eaa05a502d0ede18 = {
	.name=			"getAccessibleRole",
	.signature=		"()Ljavax/accessibility/AccessibleRole;",
	.class=			&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	.return_type=		&_jc_javax_accessibility_AccessibleRole$type,
	.param_ptypes=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$param_ptypes$getAccessibleRole$eaa05a502d0ede18,
	.signature_hash=	_JC_JLONG(0xeaa05a502d0ede18),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable, javax_swing_JRootPane__24AccessibleJRootPane.getAccessibleRole$eaa05a502d0ede18) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$linenum_table$getAccessibleRole$eaa05a502d0ede18
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JRootPane__24AccessibleJRootPane, getAccessibleRole$eaa05a502d0ede18);

_jc_javax_accessibility_AccessibleRole$object * _JC_JCNI_ATTR
_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *const env, _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *this)
{
	struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *r0;
	struct _jc_javax_accessibility_AccessibleRole$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(86);				// 0
	r1 = _JC_STATIC_FIELD(env, javax_accessibility_AccessibleRole, ROOT__5fPANE, 0);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$methods[] = {
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$getAccessibleRole$eaa05a502d0ede18
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_98[] = {
	&_jc_javax_swing_JRootPane__24AccessibleJRootPane$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[98]=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_98,
	[101]=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/accessibility/AccessibleRole",	_JC_JLONG(0x13eec6fc3dc83b49) },
	{ "javax/swing/JRootPane",	_JC_JLONG(0x83369470a2cd3968) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype _jc_javax_swing_JRootPane__24AccessibleJRootPane$type = {
    .type= {
	.name=			"javax/swing/JRootPane$AccessibleJRootPane",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xb2cd729d8d354462),
		.source_file=		"JRootPane.java",
		.instance_size=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$refs) + sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields) / sizeof(*_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields),
		.fields=		_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields,
		.num_methods=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$methods) / sizeof(*_jc_javax_swing_JRootPane__24AccessibleJRootPane$methods),
		.methods=		_jc_javax_swing_JRootPane__24AccessibleJRootPane$methods,
		.instanceof_hash_table=	_jc_javax_swing_JRootPane__24AccessibleJRootPane$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_fields,
		.outer_class=		&_jc_javax_swing_JRootPane$type,
		.num_class_depends=		sizeof(_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends) / sizeof(*_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends),
		.class_depends=		_jc_javax_swing_JRootPane__24AccessibleJRootPane$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_JRootPane__24AccessibleJRootPane= {
	    .getAccessibleRole$eaa05a502d0ede18=
		&_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18,
	},
    }
};
